import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/asset-node-proxy-agent-v5",
    "2.0.2",
    __name__[0:-6],
    "asset-node-proxy-agent-v5@2.0.2.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
